Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/__init__.py	(revision 14181)
@@ -2,7 +2,7 @@
 """
 # Make this a package.
-from ikobacustom.uniben.documents.document import SkeletonDocument
+from ikobacustom.uniben.documents.document import UnibenDocument
 
 __all__ = [
-    'SkeletonDocument',
+    'UnibenDocument',
     ]
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/document.py	(revision 14181)
@@ -24,30 +24,30 @@
 from waeup.ikoba.utils.helpers import attrs_to_fields
 from waeup.ikoba.documents.document import PublicDocumentBase
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonDocument(PublicDocumentBase):
+class UnibenDocument(PublicDocumentBase):
     """This is a document.
     """
-    grok.implements(ISkeletonDocument)
-    grok.provides(ISkeletonDocument)
+    grok.implements(IUnibenDocument)
+    grok.provides(IUnibenDocument)
 
-    form_fields_interface = ISkeletonDocument
+    form_fields_interface = IUnibenDocument
 
-SkeletonDocument = attrs_to_fields(SkeletonDocument)
+UnibenDocument = attrs_to_fields(UnibenDocument)
 
 
-class SkeletonDocumentFactory(grok.GlobalUtility):
+class UnibenDocumentFactory(grok.GlobalUtility):
     """A factory for documents.
     """
     grok.implements(IFactory)
-    grok.name(u'waeup.SkeletonDocument')
+    grok.name(u'waeup.UnibenDocument')
     title = u"Create a new document.",
     description = u"This factory instantiates new uniben documents."
 
     def __call__(self, *args, **kw):
-        return SkeletonDocument(*args, **kw)
+        return UnibenDocument(*args, **kw)
 
     def getInterfaces(self):
-        return implementedBy(SkeletonDocument)
+        return implementedBy(UnibenDocument)
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/export.py	(revision 14181)
@@ -20,13 +20,13 @@
 import grok
 from waeup.ikoba.documents.export import DocumentExporterBase
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentExporter(DocumentExporterBase):
+class UnibenDocumentExporter(DocumentExporterBase):
     """Exporter for documents.
     """
     grok.name('unibendocuments')
-    iface = ISkeletonDocument
-    class_name = 'SkeletonDocument'
-    title = _(u'Skeleton Documents')
+    iface = IUnibenDocument
+    class_name = 'UnibenDocument'
+    title = _(u'Uniben Documents')
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/interfaces.py	(revision 14181)
@@ -20,5 +20,5 @@
 
 
-class ISkeletonDocument(IPublicDocument):
+class IUnibenDocument(IPublicDocument):
     """A representation of a uniben document.
 
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_browser.py	(revision 14181)
@@ -27,7 +27,7 @@
 from zope.interface.verify import verifyObject, verifyClass
 from waeup.ikoba.documents.tests.test_batching import DocumentImportExportSetup
-from ikobacustom.uniben.documents.document import SkeletonDocument
-from ikobacustom.uniben.documents.export import SkeletonDocumentExporter
-from ikobacustom.uniben.documents.batching import SkeletonDocumentProcessor
+from ikobacustom.uniben.documents.document import UnibenDocument
+from ikobacustom.uniben.documents.export import UnibenDocumentExporter
+from ikobacustom.uniben.documents.batching import UnibenDocumentProcessor
 from ikobacustom.uniben.testing import FunctionalLayer
 
@@ -38,5 +38,5 @@
 
     def setup_for_export(self):
-        document = SkeletonDocument()
+        document = UnibenDocument()
         document.document_id = u'DOC1'
         document.title = u'My first document'
@@ -49,5 +49,5 @@
         # set values we can expect in export file
         self.setup_for_export()
-        exporter = SkeletonDocumentExporter()
+        exporter = UnibenDocumentExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -55,9 +55,9 @@
             'class_name,description,document_id,history,state,title,'
             'users_with_local_roles\r\n'
-            'SkeletonDocument,,DOC1,'
+            'UnibenDocument,,DOC1,'
             '[u\'2014-12-21 23:27:15 WAT - Document created by system\'],'
             'created,My first document,[]\r\n')
         # We can import the same file.
-        processor = SkeletonDocumentProcessor()
+        processor = UnibenDocumentProcessor()
         result = processor.doImport(
             self.outfile,
@@ -79,5 +79,5 @@
         self.assertEqual(num_fail,0)
         # We can import the same file in update mode.
-        processor = SkeletonDocumentProcessor()
+        processor = UnibenDocumentProcessor()
         result = processor.doImport(
             self.outfile,
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/tests/test_document.py	(revision 14181)
@@ -24,8 +24,8 @@
 
 from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.uniben.documents.document import SkeletonDocument
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.document import UnibenDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 
-class SkeletonDocumentTestCase(FunctionalTestCase):
+class UnibenDocumentTestCase(FunctionalTestCase):
 
     layer = FunctionalLayer
@@ -35,15 +35,15 @@
         self.assertTrue(
             verifyClass(
-                ISkeletonDocument, SkeletonDocument)
+                IUnibenDocument, UnibenDocument)
             )
         self.assertTrue(
             verifyObject(
-                ISkeletonDocument, SkeletonDocument())
+                IUnibenDocument, UnibenDocument())
             )
         return
 
-    def test_addSkeletonDocument(self):
+    def test_addUnibenDocument(self):
         container = DocumentsContainer()
-        document = createObject(u'waeup.SkeletonDocument')
+        document = createObject(u'waeup.UnibenDocument')
         document.document_id = u'DOC1'
         container.addDocument(document)
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/utils.py	(revision 14181)
@@ -22,5 +22,5 @@
 
 
-class SkeletonDocumentsUtils(DocumentsUtils):
+class UnibenDocumentsUtils(DocumentsUtils):
     """A collection of methods subject to customization.
     """
@@ -30,5 +30,5 @@
         'HTMLDocument': _('HTML Document'),
         'RESTDocument': _('REST Document'),
-        'SkeletonDocument': _('Skeleton Document'),
+        'UnibenDocument': _('Uniben Document'),
         }
 

Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py	(revision 14178)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/documents/batching.py	(revision 14181)
@@ -20,16 +20,16 @@
 import grok
 from waeup.ikoba.documents.batching import DocumentProcessorBase
-from ikobacustom.uniben.documents.interfaces import ISkeletonDocument
+from ikobacustom.uniben.documents.interfaces import IUnibenDocument
 from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
-class SkeletonDocumentProcessor(DocumentProcessorBase):
-    """A batch processor for ISkeletonDocument objects.
+class UnibenDocumentProcessor(DocumentProcessorBase):
+    """A batch processor for IUnibenDocument objects.
     """
     util_name = 'unibendocumentprocessor'
     grok.name(util_name)
 
-    name = _('Skeleton Document Processor')
-    iface = ISkeletonDocument
+    name = _('Uniben Document Processor')
+    iface = IUnibenDocument
 
-    factory_name = 'waeup.SkeletonDocument'
+    factory_name = 'waeup.UnibenDocument'